@@ -41,8 +41,6 @@ class BaseDocument(object):
 
     @classmethod
     def from_son(cls, dic):
-        klass = get_class(dic.pop('__module__'), dic.pop('__class__'))
-
         field_values = {}
         for name, value in dic.items():
             if name in cls._fields:
@@ -50,16 +48,14 @@ class BaseDocument(object):
             else:
                 field_values[name] = value
 
-        return klass(**field_values)
+        return cls(**field_values)
 
     def to_son(self):
-        data = {
-            "__module__": self.__module__,
-            "__class__": self.__class__.__name__
-        }
+        data = dict()
 
         for name, value in self._values.items():
             data[name] = self._fields[name].to_son(value)
+
         return data
 
     def validate_fields(self):
@@ -105,7 +101,7 @@ class BaseDocument(object):
                 if value is not None:
                     results.append([
                         field._reference_document_type.objects.get,
-                        ObjectId(value['__id__']),
+                        value,
                         document._values,
                         field_name
                     ])
@@ -130,10 +126,9 @@ class BaseDocument(object):
         if name in self._fields:
             is_reference_field = self.is_reference_field(self._fields[name])
             value = self._values.get(name, None)
-            is_dict = isinstance(value, dict)
 
-            if is_reference_field and is_dict and not value['__loaded__']:
-                raise LoadReferencesRequiredError("The property '%s' can't be accessed before calling 'load_references' on its instance first (%s)." % (name, self.__class__.__name__))
+            if is_reference_field and not isinstance(value, self._fields[name]._reference_document_type):
+                raise LoadReferencesRequiredError("The property '%s' can't be accessed before calling 'load_references' on its instance first (%s) or setting __lazy__ to False in the %s class." % (name, self.__class__.__name__, self.__class__.__name__))
 
             return value
 
